@@ -4,3 +4,5 @@ lraspp_kelp_presence_torchscript_path = resource_filename(
     __name__, 'LRASPP_MobileNetV3_kelp_presence_jit.pt')
 lraspp_mussel_presence_torchscript_path = resource_filename(
     __name__, 'LRASPP_MobileNetV3_mussel_presence_jit.pt')
+lraspp_kelp_species_torchscript_path = resource_filename(
+    __name__, 'LRASPP_MobileNetV3_kelp_species_jit.pt')
